@@ -26,16 +26,13 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-Werror=format-security         -fstack-clash-protection '
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-Werror=format-security         -fstack-clash-protection '
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+           '-Werror=format-security         -fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -44,8 +41,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
                      '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wformat -Werror=format-security         '
-                     '-fstack-clash-protection -g '
-                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+                     '-fstack-clash-protection',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -61,15 +57,14 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv8-a "
                 '-O3 -pipe -fstack-protector-strong -fno-plt '
                 '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                '-Werror=format-security         -fstack-clash-protection -g '
-                "-ffile-prefix-map=/build/python/src=/usr/src/debug/python' "
+                "-Werror=format-security         -fstack-clash-protection' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.10.9/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.10.9/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.10.10/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.10.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -668,22 +663,16 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -march=armv8-a -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -march=armv8-a -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-std=c99 -Wextra -Wno-unused-result '
-                             '-Wno-unused-parameter '
+                             '-fstack-clash-protection -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -691,16 +680,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-Werror=format-security         -fstack-clash-protection '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-Werror=format-security         -fstack-clash-protection '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+              '-Werror=format-security         -fstack-clash-protection',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -710,18 +696,13 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wall -march=armv8-a -O3 -pipe -fstack-protector-strong '
                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wformat -Werror=format-security         '
-                   '-fstack-clash-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+                   '-fstack-clash-protection -march=armv8-a -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
                    '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                   '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -741,20 +722,17 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                        '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-                        '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -march=armv8-a -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -766,7 +744,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -808,9 +786,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -838,8 +816,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.10.9',
- 'abs_srcdir': '/build/python/src/Python-3.10.9',
+ 'abs_builddir': '/build/python/src/Python-3.10.10',
+ 'abs_srcdir': '/build/python/src/Python-3.10.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
